@@ -1,9 +1,5 @@
-"""CLI utilities for tmuxp.
+"""CLI utilities for tmuxp."""
 
-tmuxp.cli
-~~~~~~~~~
-
-"""
 import argparse
 import logging
 import os
@@ -15,9 +11,10 @@ from libtmux.__about__ import __version__ as libtmux_version
 from libtmux.common import has_minimum_version
 from libtmux.exc import TmuxCommandNotFound
 
-from .. import exc
-from ..__about__ import __version__
-from ..log import setup_logger
+from tmuxp import exc
+from tmuxp.__about__ import __version__
+from tmuxp.log import setup_logger
+
 from .convert import command_convert, create_convert_subparser
 from .debug_info import command_debug_info, create_debug_info_subparser
 from .edit import command_edit, create_edit_subparser
@@ -39,12 +36,20 @@ if t.TYPE_CHECKING:
 
     CLIVerbosity: TypeAlias = t.Literal["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
     CLISubparserName: TypeAlias = t.Literal[
-        "ls", "load", "freeze", "convert", "edit", "import", "shell", "debug-info"
+        "ls",
+        "load",
+        "freeze",
+        "convert",
+        "edit",
+        "import",
+        "shell",
+        "debug-info",
     ]
     CLIImportSubparserName: TypeAlias = t.Literal["teamocil", "tmuxinator"]
 
 
 def create_parser() -> argparse.ArgumentParser:
+    """Create CLI :class:`argparse.ArgumentParser` for tmuxp."""
     parser = argparse.ArgumentParser(prog="tmuxp")
     parser.add_argument(
         "--version",
@@ -64,21 +69,25 @@ def create_parser() -> argparse.ArgumentParser:
     load_parser = subparsers.add_parser("load", help="load tmuxp workspaces")
     create_load_subparser(load_parser)
     shell_parser = subparsers.add_parser(
-        "shell", help="launch python shell for tmux server, session, window and pane"
+        "shell",
+        help="launch python shell for tmux server, session, window and pane",
     )
     create_shell_subparser(shell_parser)
     import_parser = subparsers.add_parser(
-        "import", help="import workspaces from teamocil and tmuxinator."
+        "import",
+        help="import workspaces from teamocil and tmuxinator.",
     )
     create_import_subparser(import_parser)
 
     convert_parser = subparsers.add_parser(
-        "convert", help="convert workspace files between yaml and json."
+        "convert",
+        help="convert workspace files between yaml and json.",
     )
     create_convert_subparser(convert_parser)
 
     debug_info_parser = subparsers.add_parser(
-        "debug-info", help="print out all diagnostic info"
+        "debug-info",
+        help="print out all diagnostic info",
     )
     create_debug_info_subparser(debug_info_parser)
 
@@ -89,7 +98,8 @@ def create_parser() -> argparse.ArgumentParser:
     create_edit_subparser(edit_parser)
 
     freeze_parser = subparsers.add_parser(
-        "freeze", help="freeze a live tmux session to a tmuxp workspace file"
+        "freeze",
+        help="freeze a live tmux session to a tmuxp workspace file",
     )
     create_freeze_subparser(freeze_parser)
 
@@ -97,6 +107,8 @@ def create_parser() -> argparse.ArgumentParser:
 
 
 class CLINamespace(argparse.Namespace):
+    """Typed :class:`argparse.Namespace` for tmuxp root-level CLI."""
+
     log_level: "CLIVerbosity"
     subparser_name: "CLISubparserName"
     import_subparser_name: t.Optional["CLIImportSubparserName"]
@@ -111,8 +123,8 @@ def cli(_args: t.Optional[t.List[str]] = None) -> None:
 
     Pass the "--help" argument to any command to see detailed help.
     See detailed documentation and examples at:
-    http://tmuxp.git-pull.com/"""
-
+    http://tmuxp.git-pull.com/
+    """
     try:
         has_minimum_version()
     except TmuxCommandNotFound:
@@ -130,7 +142,7 @@ def cli(_args: t.Optional[t.List[str]] = None) -> None:
     if args.subparser_name is None:
         parser.print_help()
         return
-    elif args.subparser_name == "load":
+    if args.subparser_name == "load":
         command_load(
             args=CLILoadNamespace(**vars(args)),
             parser=parser,
@@ -145,7 +157,7 @@ def cli(_args: t.Optional[t.List[str]] = None) -> None:
         if import_subparser_name is None:
             parser.print_help()
             return
-        elif import_subparser_name == "teamocil":
+        if import_subparser_name == "teamocil":
             command_import_teamocil(
                 workspace_file=args.workspace_file,
                 parser=parser,
@@ -186,6 +198,5 @@ def startup(config_dir: pathlib.Path) -> None:
     ----------
     str : get_workspace_dir(): Config directory to search
     """
-
     if not os.path.exists(config_dir):
         os.makedirs(config_dir)
